@@ -129,21 +129,7 @@ def download_template(args, api_address, headers):
         exit(1)
 
 
-def list_templates(args, api_address, headers):
-    access = args.public_access
-    headers = authorization(headers)
-
-    if access:
-        #api_url = api_address + "/api/templates"
-        api_url = api_address + "/api/templates/template_type/" + "10"
-
-    else:
-        file = open(env_path + "/.username", "r")
-        env_username = file.read()
-        file.close()
-
-        api_url = api_address + "/api/templates/user/name/" + env_username
-
+def list_templates(args, headers, api_url):
     try:
         response = requests.get(api_url, headers=headers)
         if len(json.loads(response.content.decode("utf-8"))) != 0:
@@ -159,6 +145,42 @@ def list_templates(args, api_address, headers):
         exit(1)
 
 
+def list_service_templates(args, api_address, headers):
+    access = args.public_access
+    headers = authorization(headers)
+
+    if access:
+        api_url = api_address + "/api/templates/template_type/" + "10"
+
+    else:
+        file = open(env_path + "/.username", "r")
+        env_username = file.read()
+        file.close()
+
+        api_url = api_address + "/api/templates/user/name/" + env_username
+
+    list_templates(args, headers, api_url)
+
+
+def list_entity_templates(args, api_address, headers):
+    access = args.public_access
+    headers = authorization(headers)
+
+    if access:
+        for entity in templates_types.values():
+            if entity != 10:
+                api_url = api_address + "/api/templates/template_type/" + str(entity)
+                list_templates(args, headers, api_url)
+    else:
+        file = open(env_path + "/.username", "r")
+        env_username = file.read()
+        file.close()
+
+        api_url = api_address + "/api/templates/user/name/" + env_username
+
+        list_templates(args, headers, api_url)
+
+
 def format_output(output):
     for key, value in output.items():
         print(key + ": " + str(value))
@@ -441,7 +463,7 @@ def main():
         if args.template_options == "get":
             download_template(args, api_address, headers)
         if args.template_options == "list":
-            list_templates(args, api_address, headers)
+            list_entity_templates(args, api_address, headers)
         if args.template_options == "version":
             if args.version_options == "list":
                 list_versions(args, api_address, headers)
@@ -452,7 +474,7 @@ def main():
         if args.template_options == "get":
             download_template(args, api_address, headers)
         if args.template_options == "list":
-            list_templates(args, api_address, headers)
+            list_service_templates(args, api_address, headers)
         if args.template_options == "version":
             if args.version_options == "list":
                 list_versions(args, api_address, headers)
\ No newline at end of file
